==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_fields/TOOLUSAGEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour TOOLUSAGEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TOOLUSAGEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEUSED"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TOOLUSAGEID_Type", propOrder = {
    "toolid",
    "departmentid",
    "activityid",
    "dateused",
    "jobsequence"
})
public class TOOLUSAGEID_Type {

    @XmlElement(name = "TOOLID", required = true)
    protected TOOLID toolid;
    @XmlElement(name = "DEPARTMENTID", required = true)
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "ACTIVITYID", required = true)
    protected ACTIVITYID activityid;
    @XmlElement(name = "DATEUSED", required = true)
    protected DATETIME dateused;
    @XmlElement(name = "JOBSEQUENCE")
    protected Long jobsequence;

    /**
     * Obtient la valeur de la propriété toolid.
     * 
     * @return
     *     possible object is
     *     {@link TOOLID }
     *     
     */
    public TOOLID getTOOLID() {
        return toolid;
    }

    /**
     * Définit la valeur de la propriété toolid.
     * 
     * @param value
     *     allowed object is
     *     {@link TOOLID }
     *     
     */
    public void setTOOLID(TOOLID value) {
        this.toolid = value;
    }

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Obtient la valeur de la propriété activityid.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Définit la valeur de la propriété activityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Obtient la valeur de la propriété dateused.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEUSED() {
        return dateused;
    }

    /**
     * Définit la valeur de la propriété dateused.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEUSED(DATETIME value) {
        this.dateused = value;
    }

    /**
     * Obtient la valeur de la propriété jobsequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Définit la valeur de la propriété jobsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/TOOLUSAGEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for TOOLUSAGEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TOOLUSAGEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEUSED"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TOOLUSAGEID_Type", propOrder = {
    "toolid",
    "departmentid",
    "activityid",
    "dateused",
    "jobsequence"
})
public class TOOLUSAGEID_Type {

    @XmlElement(name = "TOOLID", required = true)
    protected TOOLID toolid;
    @XmlElement(name = "DEPARTMENTID", required = true)
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "ACTIVITYID", required = true)
    protected ACTIVITYID activityid;
    @XmlElement(name = "DATEUSED", required = true)
    protected DATETIME dateused;
    @XmlElement(name = "JOBSEQUENCE")
    protected Long jobsequence;

    /**
     * Gets the value of the toolid property.
     * 
     * @return
     *     possible object is
     *     {@link TOOLID }
     *     
     */
    public TOOLID getTOOLID() {
        return toolid;
    }

    /**
     * Sets the value of the toolid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TOOLID }
     *     
     */
    public void setTOOLID(TOOLID value) {
        this.toolid = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the activityid property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Sets the value of the activityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Gets the value of the dateused property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEUSED() {
        return dateused;
    }

    /**
     * Sets the value of the dateused property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEUSED(DATETIME value) {
        this.dateused = value;
    }

    /**
     * Gets the value of the jobsequence property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Sets the value of the jobsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

}
